Class: LinodeOpenapiClient::FilterAndSortCriteria

Inherits:
Object
  • Object
show all
Defined in:
lib/linode_openapi_client/models/filter_and_sort_criteria.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ FilterAndSortCriteria

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/linode_openapi_client/models/filter_and_sort_criteria.rb', line 115

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LinodeOpenapiClient::FilterAndSortCriteria` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LinodeOpenapiClient::FilterAndSortCriteria`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'order_by')
    self.order_by = attributes[:'order_by']
  end

  if attributes.key?(:'neq')
    self.neq = attributes[:'neq']
  end

  if attributes.key?(:'_or')
    if (value = attributes[:'_or']).is_a?(Array)
      self._or = value
    end
  end

  if attributes.key?(:'lte')
    self.lte = attributes[:'lte']
  end

  if attributes.key?(:'gte')
    self.gte = attributes[:'gte']
  end

  if attributes.key?(:'_and')
    if (value = attributes[:'_and']).is_a?(Array)
      self._and = value
    end
  end

  if attributes.key?(:'lt')
    self.lt = attributes[:'lt']
  end

  if attributes.key?(:'order')
    self.order = attributes[:'order']
  else
    self.order = 'asc'
  end

  if attributes.key?(:'gt')
    self.gt = attributes[:'gt']
  end

  if attributes.key?(:'contains')
    self.contains = attributes[:'contains']
  end
end

Instance Attribute Details

#_andObject

All conditions need to be true.



34
35
36
# File 'lib/linode_openapi_client/models/filter_and_sort_criteria.rb', line 34

def _and
  @_and
end

#_orObject

At least one condition needs to be true.



25
26
27
# File 'lib/linode_openapi_client/models/filter_and_sort_criteria.rb', line 25

def _or
  @_or
end

#containsObject

The provided string needs to be in the value.



46
47
48
# File 'lib/linode_openapi_client/models/filter_and_sort_criteria.rb', line 46

def contains
  @contains
end

#gtObject

The value needs to be greater than the provided number.



43
44
45
# File 'lib/linode_openapi_client/models/filter_and_sort_criteria.rb', line 43

def gt
  @gt
end

#gteObject

The value needs to be greater than or equal to the provided number.



31
32
33
# File 'lib/linode_openapi_client/models/filter_and_sort_criteria.rb', line 31

def gte
  @gte
end

#ltObject

The value needs to be less than the provided number.



37
38
39
# File 'lib/linode_openapi_client/models/filter_and_sort_criteria.rb', line 37

def lt
  @lt
end

#lteObject

The value needs to be less than or equal to the provided number.



28
29
30
# File 'lib/linode_openapi_client/models/filter_and_sort_criteria.rb', line 28

def lte
  @lte
end

#neqObject

The provided string is left out of the results.



22
23
24
# File 'lib/linode_openapi_client/models/filter_and_sort_criteria.rb', line 22

def neq
  @neq
end

#orderObject

Sort in ascending (asc) or descending (desc) order. This defaults to asc. Requires ‘+order_by`.



40
41
42
# File 'lib/linode_openapi_client/models/filter_and_sort_criteria.rb', line 40

def order
  @order
end

#order_byObject

Order results based on the provided attribute. The attribute needs to be filterable.



19
20
21
# File 'lib/linode_openapi_client/models/filter_and_sort_criteria.rb', line 19

def order_by
  @order_by
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
# File 'lib/linode_openapi_client/models/filter_and_sort_criteria.rb', line 258

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = LinodeOpenapiClient.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



87
88
89
# File 'lib/linode_openapi_client/models/filter_and_sort_criteria.rb', line 87

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/linode_openapi_client/models/filter_and_sort_criteria.rb', line 71

def self.attribute_map
  {
    :'order_by' => :'+order_by',
    :'neq' => :'+neq',
    :'_or' => :'+or',
    :'lte' => :'+lte',
    :'gte' => :'+gte',
    :'_and' => :'+and',
    :'lt' => :'+lt',
    :'order' => :'+order',
    :'gt' => :'+gt',
    :'contains' => :'+contains'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
# File 'lib/linode_openapi_client/models/filter_and_sort_criteria.rb', line 234

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



108
109
110
111
# File 'lib/linode_openapi_client/models/filter_and_sort_criteria.rb', line 108

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/linode_openapi_client/models/filter_and_sort_criteria.rb', line 92

def self.openapi_types
  {
    :'order_by' => :'String',
    :'neq' => :'String',
    :'_or' => :'Array<Object>',
    :'lte' => :'Float',
    :'gte' => :'Float',
    :'_and' => :'Array<Object>',
    :'lt' => :'Float',
    :'order' => :'String',
    :'gt' => :'Float',
    :'contains' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/linode_openapi_client/models/filter_and_sort_criteria.rb', line 204

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      order_by == o.order_by &&
      neq == o.neq &&
      _or == o._or &&
      lte == o.lte &&
      gte == o.gte &&
      _and == o._and &&
      lt == o.lt &&
      order == o.order &&
      gt == o.gt &&
      contains == o.contains
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



329
330
331
332
333
334
335
336
337
338
339
340
341
# File 'lib/linode_openapi_client/models/filter_and_sort_criteria.rb', line 329

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


221
222
223
# File 'lib/linode_openapi_client/models/filter_and_sort_criteria.rb', line 221

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



227
228
229
# File 'lib/linode_openapi_client/models/filter_and_sort_criteria.rb', line 227

def hash
  [order_by, neq, _or, lte, gte, _and, lt, order, gt, contains].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



177
178
179
180
181
# File 'lib/linode_openapi_client/models/filter_and_sort_criteria.rb', line 177

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



305
306
307
# File 'lib/linode_openapi_client/models/filter_and_sort_criteria.rb', line 305

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



311
312
313
314
315
316
317
318
319
320
321
322
323
# File 'lib/linode_openapi_client/models/filter_and_sort_criteria.rb', line 311

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



299
300
301
# File 'lib/linode_openapi_client/models/filter_and_sort_criteria.rb', line 299

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



185
186
187
188
189
190
# File 'lib/linode_openapi_client/models/filter_and_sort_criteria.rb', line 185

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  order_validator = EnumAttributeValidator.new('String', ["asc", "desc"])
  return false unless order_validator.valid?(@order)
  true
end