Method: LinodeOpenapiClient::GetLinodeConfigs200ResponseDataInnerInterfacesInner#ipam_address
- Defined in:
- lib/linode_openapi_client/models/get_linode_configs200_response_data_inner_interfaces_inner.rb
#ipam_address ⇒ Object
This Network Interface’s private IP address in Classless Inter-Domain Routing (CIDR) notation. For vlan purpose Interfaces: - Must be unique among the Linode’s Interfaces to avoid conflicting addresses. - Should be unique among devices attached to the VLAN to avoid conflict. - The Linode is configured to use this address for the associated Interface upon reboot if Network Helper is enabled. If Network Helper is disabled, the address can be enabled with [manual static IP configuration](www.linode.com/docs/guides/manual-network-configuration/). For public purpose Interfaces: - In requests, must be an empty string (‘\“\”`) or null if included. - In responses, always returns null. For vpc purpose Interfaces: - In requests, must be an empty string (`\“\”`) or null if included. - In responses, always returns null.
26 27 28 |
# File 'lib/linode_openapi_client/models/get_linode_configs200_response_data_inner_interfaces_inner.rb', line 26 def ipam_address @ipam_address end |