Method: LinodeOpenapiClient::GetLinodeConfigs200ResponseDataInnerInterfacesInner#purpose
- Defined in:
- lib/linode_openapi_client/models/get_linode_configs200_response_data_inner_interfaces_inner.rb
#purpose ⇒ Object
The type of Interface. - public - Only one public Interface per Linode can be defined. - The Linode’s default public IPv4 address is assigned to the public Interface. - A Linode must have a public Interface in the first/eth0 position to be reachable via the public internet upon boot without additional system configuration. If no public Interface is configured, the Linode is not directly reachable via the public internet. In this case, access can only be established via [LISH](www.linode.com/docs/products/compute/compute-instances/guides/lish/) or other Linodes connected to the same VLAN or VPC. - vlan - Configuring a vlan purpose Interface attaches this Linode to the VLAN with the specified label. - The Linode is configured to use the specified ipam_address, if any. - vpc - Configuring a vpc purpose Interface attaches this Linode to the existing VPC Subnet with the specified subnet_id. - When the Interface is activated, the Linode is configured to use an IP address from the range in the assigned VPC Subnet. See ipv4.vpc for more information.
20 21 22 |
# File 'lib/linode_openapi_client/models/get_linode_configs200_response_data_inner_interfaces_inner.rb', line 20 def purpose @purpose end |