Method: LinodeOpenapiClient::NodeBalancer4#list_invalid_properties
- Defined in:
- lib/linode_openapi_client/models/node_balancer4.rb
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/linode_openapi_client/models/node_balancer4.rb', line 161 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@client_conn_throttle.nil? && @client_conn_throttle > 20 invalid_properties.push('invalid value for "client_conn_throttle", must be smaller than or equal to 20.') end if !@client_conn_throttle.nil? && @client_conn_throttle < 0 invalid_properties.push('invalid value for "client_conn_throttle", must be greater than or equal to 0.') end if !@label.nil? && @label.to_s.length > 32 invalid_properties.push('invalid value for "label", the character length must be smaller than or equal to 32.') end if !@label.nil? && @label.to_s.length < 3 invalid_properties.push('invalid value for "label", the character length must be great than or equal to 3.') end pattern = Regexp.new(/[a-zA-Z0-9-_]{3,32}/) if !@label.nil? && @label !~ pattern invalid_properties.push("invalid value for \"label\", must conform to the pattern #{pattern}.") end invalid_properties end |