Method: LinodeOpenapiClient::PostCloneLinodeInstanceRequest#region

Defined in:
lib/linode_openapi_client/models/post_clone_linode_instance_request.rb

#regionObject

This is the Region where the Linode will be deployed. To view all available Regions you can deploy to, run [List regions](techdocs.akamai.com/linode-api/reference/get-regions). - Region can only be provided and is required when cloning to a new Linode.



24
25
26
# File 'lib/linode_openapi_client/models/post_clone_linode_instance_request.rb', line 24

def region
  @region
end