Method: LinodeOpenapiClient::PostCloneVolumeRequest#list_invalid_properties

Defined in:
lib/linode_openapi_client/models/post_clone_volume_request.rb

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/linode_openapi_client/models/post_clone_volume_request.rb', line 70

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @label.nil?
    invalid_properties.push('invalid value for "label", label cannot be nil.')
  end

  if @label.to_s.length > 32
    invalid_properties.push('invalid value for "label", the character length must be smaller than or equal to 32.')
  end

  if @label.to_s.length < 1
    invalid_properties.push('invalid value for "label", the character length must be great than or equal to 1.')
  end

  pattern = Regexp.new(/^[a-zA-Z]((?!--|__)[a-zA-Z0-9-_])+$/)
  if @label !~ pattern
    invalid_properties.push("invalid value for \"label\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end