Method: LinodeOpenapiClient::PostUploadImageRequest#list_invalid_properties
- Defined in:
- lib/linode_openapi_client/models/post_upload_image_request.rb
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/linode_openapi_client/models/post_upload_image_request.rb', line 110 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @region.nil? invalid_properties.push('invalid value for "region", region cannot be nil.') end if !@tags.nil? && @tags.length > 500 invalid_properties.push('invalid value for "tags", number of items must be less than or equal to 500.') end if !@tags.nil? && @tags.length < 0 invalid_properties.push('invalid value for "tags", number of items must be greater than or equal to 0.') end if @label.nil? invalid_properties.push('invalid value for "label", label cannot be nil.') end invalid_properties end |