Method: LinodeOpenapiClient::PutObjectStorageKey200Response#limited
- Defined in:
- lib/linode_openapi_client/models/put_object_storage_key200_response.rb
#limited ⇒ Object
Read-only Whether this Object Storage key limits access to specific buckets and permissions. Returns false if this key grants full access. > 📘 > > The bucket_access array that contains limited Object Storage key settings doesn’t appear in this response. Store this key’s id from the response and run [Get an Object Storage key](techdocs.akamai.com/linode-api/reference/get-object-storage-key) to view these settings.
26 27 28 |
# File 'lib/linode_openapi_client/models/put_object_storage_key200_response.rb', line 26 def limited @limited end |